from __future__ import unicode_literals

from telesign.score import ScoreClient as _ScoreClient


class ScoreClient(_ScoreClient):
    """
    Score provides risk information about a specified phone number.
    """

    def __init__(self, customer_id, api_key, rest_endpoint="https://rest-ww.telesign.com", **kwargs):
        super(ScoreClient, self).__init__(customer_id, api_key, rest_endpoint=rest_endpoint, **kwargs)



from __future__ import unicode_literals

from telesign.messaging import MessagingClient as _MessagingClient

OMNI_MESSAGING_RESOURCE = "/v1/omnichannel"

class MessagingClient(_MessagingClient):
    """
    TeleSign's Messaging API allows you to easily send SMS messages. You can send alerts, reminders, and notifications,
    or you can send verification messages containing one-time passcodes (OTP).
    """

    def __init__(self, customer_id, api_key, rest_endpoint="https://rest-ww.telesign.com", **kwargs):
        super(MessagingClient, self).__init__(customer_id, api_key, rest_endpoint=rest_endpoint, **kwargs)

    """
    Send a message to the target recipient using any of Telesign's supported channels.
    @param params All required and optional parameters well-structured according to the API documentation.

    See  https://developer.telesign.com/enterprise/reference/sendadvancedmessage for detailed API documentation.
    """
    def omniMessage(self, params={}):
        return self.post(OMNI_MESSAGING_RESOURCE, json_fields=params)


from __future__ import unicode_literals

from telesign.rest import RestClient

TELEBUREAU_CREATE_RESOURCE = "/v1/telebureau/event"
TELEBUREAU_RETRIEVE_RESOURCE = "/v1/telebureau/event/{reference_id}"
TELEBUREAU_DELETE_RESOURCE = "/v1/telebureau/event/{reference_id}"


class TelebureauClient(RestClient):
    """
    TeleBureau is a service is based on TeleSign's watchlist, which is a proprietary database containing verified phone
    numbers of users known to have committed online fraud. TeleSign crowd-sources this information from its customers.
    Participation is voluntary, but you have to contribute in order to benefit.
    """

    def __init__(self, customer_id, api_key, rest_endpoint='https://rest-ww.telesign.com', **kwargs):
        super(TelebureauClient, self).__init__(customer_id, api_key, rest_endpoint=rest_endpoint, **kwargs)

    def create_event(self, phone_number, fraud_type, occurred_at, **params):
        """
        Creates a telebureau event corresponding to supplied data.

        See https://developer.telesign.com/docs/telebureau-api for detailed API documentation.
        """
        return self.post(TELEBUREAU_CREATE_RESOURCE,
                         phone_number=phone_number,
                         fraud_type=fraud_type,
                         occurred_at=occurred_at,
                         **params)

    def retrieve_event(self, reference_id, **params):
        """
        Retrieves the fraud event status. You make this call in your web application after completion of create
        transaction for a telebureau event.

        See https://developer.telesign.com/docs/telebureau-api for detailed API documentation.
        """
        return self.get(TELEBUREAU_RETRIEVE_RESOURCE.format(reference_id=reference_id),
                        **params)

    def delete_event(self, reference_id, **params):
        """
        Deletes a previously submitted fraud event. You make this call in your web application after completion of the
        create transaction for a telebureau event.

        See https://developer.telesign.com/docs/telebureau-api for detailed API documentation.
        """
        return self.delete(TELEBUREAU_DELETE_RESOURCE.format(reference_id=reference_id),
                           **params)



from __future__ import unicode_literals

from telesign.phoneid import PhoneIdClient as _PhoneIdClient

PHONEID_STANDARD_RESOURCE = "/v1/phoneid/standard/{phone_number}"
PHONEID_SCORE_RESOURCE = "/v1/phoneid/score/{phone_number}"
PHONEID_CONTACT_RESOURCE = "/v1/phoneid/contact/{phone_number}"
PHONEID_LIVE_RESOURCE = "/v1/phoneid/live/{phone_number}"
PHONEID_NUMBER_DEACTIVATION_RESOURCE = "/v1/phoneid/number_deactivation/{phone_number}"


class PhoneIdClient(_PhoneIdClient):
    """
    PhoneID is a set of REST APIs that deliver deep phone number data attributes that help optimize the end user
    verification process and evaluate risk.

    TeleSign PhoneID provides a wide range of risk assessment indicators on the number to help confirm user identity,
    delivering real-time decision making throughout the number lifecycle and ensuring only legitimate users are
    creating accounts and accessing your applications.
    """

    def __init__(self, customer_id, api_key, rest_endpoint='https://rest-ww.telesign.com', **kwargs):
        super(PhoneIdClient, self).__init__(customer_id, api_key, rest_endpoint=rest_endpoint, **kwargs)

    def standard(self, phone_number, **params):
        """
        The PhoneID Standard API that provides phone type and telecom carrier information to identify which phone
        numbers can receive SMS messages and/or a potential fraud risk.
        
        See https://developer.telesign.com/docs/rest_phoneid-standard for detailed API documentation.
        """
        return self.get(PHONEID_STANDARD_RESOURCE.format(phone_number=phone_number),
                        **params)

    def score(self, phone_number, ucid, **params):
        """
        Score is an API that delivers reputation scoring based on phone number intelligence, traffic patterns, machine
        learning, and a global data consortium.

        See https://developer.telesign.com/docs/rest_api-phoneid-score for detailed API documentation.
        """
        return self.get(PHONEID_SCORE_RESOURCE.format(phone_number=phone_number),
                        ucid=ucid,
                        **params)

    def contact(self, phone_number, ucid, **params):
        """
        The PhoneID Contact API delivers contact information related to the subscriber's phone number to provide another
        set of indicators for established risk engines.

        See https://developer.telesign.com/docs/rest_api-phoneid-contact for detailed API documentation.
        """
        return self.get(PHONEID_CONTACT_RESOURCE.format(phone_number=phone_number),
                        ucid=ucid,
                        **params)

    def live(self, phone_number, ucid, **params):
        """
        The PhoneID Live API delivers insights such as whether a phone is active or disconnected, a device is reachable
        or unreachable and its roaming status.

        See https://developer.telesign.com/docs/rest_api-phoneid-live for detailed API documentation.
        """
        return self.get(PHONEID_LIVE_RESOURCE.format(phone_number=phone_number),
                        ucid=ucid,
                        **params)

    def number_deactivation(self, phone_number, ucid, **params):
        """
        The PhoneID Number Deactivation API determines whether a phone number has been deactivated and when, based on
        carriers' phone number data and TeleSign's proprietary analysis.

        See https://developer.telesign.com/docs/rest_api-phoneid-number-deactivation for detailed API documentation.
        """
        return self.get(PHONEID_NUMBER_DEACTIVATION_RESOURCE.format(phone_number=phone_number),
                        ucid=ucid,
                        **params)



from __future__ import unicode_literals

from telesign.voice import VoiceClient as _VoiceClient


class VoiceClient(_VoiceClient):
    """
    TeleSign's Voice API allows you to easily send voice messages. You can send alerts, reminders, and notifications,
    or you can send verification messages containing time-based, one-time passcodes (TOTP).
    """

    def __init__(self, customer_id, api_key, rest_endpoint="https://rest-ww.telesign.com", **kwargs):
        super(VoiceClient, self).__init__(customer_id, api_key, rest_endpoint=rest_endpoint, **kwargs)
